CalendarPeriod class final

A CalendarPeriod represents the abstract concept of a time period that has a canonical start. Grammatically, "the start of the current CalendarPeriod." All calendar times begin at midnight UTC.

Constructors

CalendarPeriod(String value)
const
CalendarPeriod.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const CalendarPeriod
The default value for CalendarPeriod.
calendarPeriodUnspecified → const CalendarPeriod
Undefined period, raises an error.
day → const CalendarPeriod
A day.
fortnight → const CalendarPeriod
A fortnight. The first calendar fortnight of the year begins at the start of week 1 according to ISO 8601.
half → const CalendarPeriod
A half-year. Half-years start on dates 1-Jan and 1-Jul.
month → const CalendarPeriod
A month.
quarter → const CalendarPeriod
A quarter. Quarters start on dates 1-Jan, 1-Apr, 1-Jul, and 1-Oct of each year.
week → const CalendarPeriod
A week. Weeks begin on Monday, following ISO 8601.
year → const CalendarPeriod
A year.