Date class final

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:

  • A full date, with non-zero year, month, and day values.
  • A month and day, with a zero year (for example, an anniversary).
  • A year on its own, with a zero month and a zero day.
  • A year and month, with a zero day (for example, a credit card expiration date).

Related types:

  • google.type.TimeOfDay
  • google.type.DateTime
  • google.protobuf.Timestamp

Constructors

Date({int year = 0, int month = 0, int day = 0})
Date.fromJson(Object? j)
factory

Properties

day int
Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.
final
hashCode int
The hash code for this object.
no setterinherited
month int
Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int
Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String