Month class final

Represents a month in the Gregorian calendar.

Constructors

Month(String value)
const
Month.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Month
The default value for Month.
april → const Month
The month of April.
august → const Month
The month of August.
december → const Month
The month of December.
february → const Month
The month of February.
january → const Month
The month of January.
july → const Month
The month of July.
june → const Month
The month of June.
march → const Month
The month of March.
may → const Month
The month of May.
monthUnspecified → const Month
The unspecified month.
november → const Month
The month of November.
october → const Month
The month of October.
september → const Month
The month of September.