addressLines property
Unstructured address lines describing the lower levels of an address.
Because values in address_lines do not have type information and may
sometimes contain multiple values in a single field (for example,
"Austin, TX"), it is important that the line order is clear. The order of
address lines should be "envelope order" for the country or region of the
address. In places where this can vary (for example, Japan),
address_language is used to make it explicit (for example, "ja" for
large-to-small ordering and "ja-Latn" or "en" for small-to-large). In this
way, the most specific line of an address can be selected based on the
language.
The minimum permitted structural representation of an address consists
of a region_code with all remaining information placed in the
address_lines. It would be possible to format such an address very
approximately without geocoding, but no semantic reasoning could be
made about any of the address components until it was at least
partially resolved.
Creating an address only containing a region_code and address_lines and
then geocoding is the recommended way to handle completely unstructured
addresses (as opposed to guessing which parts of the address should be
localities or administrative areas).
Implementation
final List<String> addressLines;