sublocality property
Optional. Sublocality of the address. For example, this can be a neighborhood, borough, or district.
Implementation
final String sublocality;
Optional. Sublocality of the address. For example, this can be a neighborhood, borough, or district.
final String sublocality;